# Example that shows how to analyse single particles using LCIO format
# Run it using https://atlaswww.hep.anl.gov/asc/jas4pp/ 
# author: S.Chekanov (ANL)

from org.lcsim.event import *
from org.lcsim.util import *
from hep.physics.vec import *
from java.util import *
from java.io import *
from org.lcsim.lcio import LCIOReader
from hep.io.sio import SIOReader
from hep.lcio.implementation.sio import SIOLCReader
from hep.lcio.implementation.io import LCFactory
from hep.lcio.event import *
from hep.lcio.io import *
from jhplot import *  # import graphics
from hephysics.particle import LParticle 
from math import *
from java.awt import *
import os,sys


if (len(sys.argv) != 2):
       print "Please specify input directory: pgu1.py input "
       sys.exit()
indir=sys.argv[1]


# make list of files..
import glob
files=glob.glob(indir+"/*.slcio")
factory = LCFactory.getInstance()
reader = factory.createLCReader()
reader.open(files)
h1=H1D("RecoClusters",100,-2,2)
h2=H1D("PFO",100,-2,2)

nEvent=0
while(1):
     evt=reader.readNextEvent()
     if (evt == None): break
     nEvent=nEvent+1
     # print " file event: ",evt.getEventNumber(), " run=",evt.getRunNumber()
     if (nEvent%100==0): print "# Event: ",nEvent
     strVec = evt.getCollectionNames()
     if nEvent == 1:
            for col in  strVec:
                           print col           

     # truth-level particles
     # task: take only particles in the central region
     col = evt.getCollection("MCParticle")
     nMc=col.getNumberOfElements()
     true_par=[]
     for i in range(nMc): # loop over all particles 
       par=col.getElementAt(i)
       if(par.getGeneratorStatus() == 1 and par.getCharge() !=0):
              vertex = par.getVertex();
              pdg=par.getPDG()
              momentum = par.getMomentum()
              ee=par.getEnergy()
              mass=par.getMass()
              px=momentum[0]
              py=momentum[1]
              pz=momentum[2]
              charge=par.getCharge()
              p=LParticle(px,py,pz,ee,mass)
              if (abs(p.pseudoRapidity())<1.3):  true_par.append(p)  

# take the most central region
     if (len(true_par)==0): continue


# See API: http://www.lcsim.org/sites/lcsim/apidocs/org/lcsim/event/
     col = evt.getCollection("PandoraPFOCollection")
     n = col.getNumberOfElements()
     pPFO=LParticle()
     for i in range(n):
          pa=col.getElementAt(i)
          charge=pa.getCharge()
          p4=pa.getMomentum()  
          ee=pa.getEnergy() 
          typep=pa.getType() # type
          p=LParticle(p4[0],p4[1],p4[2],ee)
          pPFO.add(p)     


     col = evt.getCollection("ReconClusters")
     n = col.getNumberOfElements()
     pcluster=LParticle()
     for i in range(n):
          pa=col.getElementAt(i)
          p4=pa.getPosition()
          ee=pa.getEnergy()
          tmp = sqrt(p4[0]*p4[0] + p4[1]*p4[1] + p4[2]*p4[2])
          px =  ee*p4[0]/tmp
          py =  ee*p4[1]/tmp
          pz =  ee*p4[2]/tmp
          typep=pa.getType() # type
          p=LParticle(px,py,pz,ee)
          pcluster.add(p)

     eT=true_par[0].getE()
     r1=pcluster.getE()
     r2=pPFO.getE()
     if (nEvent%50==0): 
        print nEvent,"truth=%.2f PFO=%.2f Clusters=%.2f [GeV]"%(eT,r2,r1) 

     h1.fill((r1-eT)/eT)
     h2.fill((r2-eT)/eT)

reader.close()


c1=HPlot()
c1.visible()
c1.setAutoRange()
c1.setMarginLeft(100)
c1.setNameX("[E(reco)-E(true)] / E(true)")
c1.setNameY("Events")
c1.setRangeX(-1.1,0.5)
print h1.entries(), h2.entries()
h1.scale(1.0/h1.entries())
h1.setLineStyle(1)
h1.setPenWidth(3)
h1.setColor(Color.red)
h1.setErrColor(Color.red)

h2.scale(1.0/h2.entries())
h2.setLineStyle(0)
h2.setPenWidth(3)

c1.draw([h1,h2])

if not os.path.exists("figs"): # make figure 
    os.makedirs("figs")
c1.export("figs/"+indir+".pdf")
print "Created figs/"+indir+".pdf"

